==> ovirt-engine-sdk-java-4.0.2.tar.gz: ovirt-engine-sdk-java-4.0.2/target/generated-sources/org/ovirt/engine/sdk4/services/HostStorageService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.HostStorage;

public interface HostStorageService extends Service {
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Indicates if the status of the LUNs in the storage should be checked.
         * Checking the status of the LUN is an heavy weight operation and
         * this data is not always needed by the user.
         * This parameter will give the option to not perform the status check of the LUNs.
         * 
         * The default is `true` for backward compatibility.
         * 
         * Here an example with the LUN status :
         * 
         * [source,xml]
         * ----
         * <host_storage id="360014051136c20574f743bdbd28177fd">
         *   <logical_units>
         *     <logical_unit id="360014051136c20574f743bdbd28177fd">
         *       <lun_mapping>0</lun_mapping>
         *       <paths>1</paths>
         *       <product_id>lun0</product_id>
         *       <serial>SLIO-ORG_lun0_1136c205-74f7-43bd-bd28-177fd5ce6993</serial>
         *       <size>10737418240</size>
         *       <status>used</status>
         *       <vendor_id>LIO-ORG</vendor_id>
         *       <volume_group_id>O9Du7I-RahN-ECe1-dZ1w-nh0b-64io-MNzIBZ</volume_group_id>
         *     </logical_unit>
         *   </logical_units>
         *   <type>iscsi</type>
         *   <host id="8bb5ade5-e988-4000-8b93-dbfc6717fe50"/>
         * </host_storage>
         * ----
         * 
         * Here an example without the LUN status :
         * 
         * [source,xml]
         * ----
         * <host_storage id="360014051136c20574f743bdbd28177fd">
         *   <logical_units>
         *     <logical_unit id="360014051136c20574f743bdbd28177fd">
         *       <lun_mapping>0</lun_mapping>
         *       <paths>1</paths>
         *       <product_id>lun0</product_id>
         *       <serial>SLIO-ORG_lun0_1136c205-74f7-43bd-bd28-177fd5ce6993</serial>
         *       <size>10737418240</size>
         *       <vendor_id>LIO-ORG</vendor_id>
         *       <volume_group_id>O9Du7I-RahN-ECe1-dZ1w-nh0b-64io-MNzIBZ</volume_group_id>
         *     </logical_unit>
         *   </logical_units>
         *   <type>iscsi</type>
         *   <host id="8bb5ade5-e988-4000-8b93-dbfc6717fe50"/>
         * </host_storage>
         * ----
         */
        ListRequest reportStatus(Boolean reportStatus);
    }
    
    public interface ListResponse extends Response {
        List<HostStorage> storages();
    }
    
    ListRequest list();
    
    StorageService storageService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.0.tar.gz: ovirt-engine-sdk-java-4.1.0/target/generated-sources/org/ovirt/engine/sdk4/services/HostStorageService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.HostStorage;

/**
 * A service to manage host storages.
 */
public interface HostStorageService extends Service {
    /**
     * Get list of storages.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/hosts/123/storage
     * ----
     * 
     * The XML response you get will be like this one:
     * 
     * [source,xml]
     * ----
     * <host_storages>
     *   <host_storage id="123">
     *     ...
     *   </host_storage>
     *   ...
     * </host_storages>
     * ----
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Indicates if the status of the LUNs in the storage should be checked.
         * Checking the status of the LUN is an heavy weight operation and
         * this data is not always needed by the user.
         * This parameter will give the option to not perform the status check of the LUNs.
         * 
         * The default is `true` for backward compatibility.
         * 
         * Here an example with the LUN status :
         * 
         * [source,xml]
         * ----
         * <host_storage id="123">
         *   <logical_units>
         *     <logical_unit id="123">
         *       <lun_mapping>0</lun_mapping>
         *       <paths>1</paths>
         *       <product_id>lun0</product_id>
         *       <serial>123</serial>
         *       <size>10737418240</size>
         *       <status>used</status>
         *       <vendor_id>LIO-ORG</vendor_id>
         *       <volume_group_id>123</volume_group_id>
         *     </logical_unit>
         *   </logical_units>
         *   <type>iscsi</type>
         *   <host id="123"/>
         * </host_storage>
         * ----
         * 
         * Here an example without the LUN status :
         * 
         * [source,xml]
         * ----
         * <host_storage id="123">
         *   <logical_units>
         *     <logical_unit id="123">
         *       <lun_mapping>0</lun_mapping>
         *       <paths>1</paths>
         *       <product_id>lun0</product_id>
         *       <serial>123</serial>
         *       <size>10737418240</size>
         *       <vendor_id>LIO-ORG</vendor_id>
         *       <volume_group_id>123</volume_group_id>
         *     </logical_unit>
         *   </logical_units>
         *   <type>iscsi</type>
         *   <host id="123"/>
         * </host_storage>
         * ----
         */
        ListRequest reportStatus(Boolean reportStatus);
    }
    
    /**
     * Get list of storages.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/hosts/123/storage
     * ----
     * 
     * The XML response you get will be like this one:
     * 
     * [source,xml]
     * ----
     * <host_storages>
     *   <host_storage id="123">
     *     ...
     *   </host_storage>
     *   ...
     * </host_storages>
     * ----
     */
    public interface ListResponse extends Response {
        /**
         * Retrieved list of storages.
         */
        List<HostStorage> storages();
    }
    
    /**
     * Get list of storages.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/hosts/123/storage
     * ----
     * 
     * The XML response you get will be like this one:
     * 
     * [source,xml]
     * ----
     * <host_storages>
     *   <host_storage id="123">
     *     ...
     *   </host_storage>
     *   ...
     * </host_storages>
     * ----
     */
    ListRequest list();
    
    /**
     * Reference to a service managing the storage.
     */
    StorageService storageService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
